import React, { useState, useEffect } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';

const AddCustomer = () => {
  const navigate = useNavigate();
  const [customerData, setCustomerData] = useState({
    firstname: '',
    lastname: '',
    age: '',
    gender: '',
    email: '',
    address_line_1: '',
    address_line_2: '',
    nearby_landmark: '',
    pincode: '',
    city_id: '',
    mobile: '',
  });
  const [cities, setCities] = useState([]);

  // useEffect(() => {
  //   const fetchCities = async () => {
  //     try {
  //       const response = await axiosInstance.get('/cities');
  //       if (Array.isArray(response.data)) {
  //         setCities(response.data);
  //       } else {
  //         console.error('Error: Data is not an array', response.data);
  //       }
  //     } catch (error) {
  //       console.error('Error fetching cities:', error.response || error.message);
  //     }
  //   };

  //   fetchCities();
  // }, []);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setCustomerData({
      ...customerData,
      [name]: value,
    });
  };

  const handleAddCustomerSubmit = async (e) => {
    e.preventDefault();
    try {
      await axiosInstance.post('http://localhost:5000/customers', customerData);
      navigate('/customers');
    } catch (error) {
      console.error('Error adding customer:', error.response || error.message);
    }
  };

  return (
    <div className="flex flex-row">
      <Sidebar />
      <div className="w-full flex flex-col min-h-screen text-black">
        <div className="min-h-screen text-gray-800 p-6">
          <div className="flex justify-between items-center mb-6">
            <h1 className="text-2xl font-semibold text-blue-900">Add Customer</h1>
            <Link to="/CategoryList" className="text-blue-900">Skip for now</Link>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
            <div className="space-y-6">
              <div className="text-center">
                <div className="inline-block relative">
                  <div className="bg-gray-300 w-24 h-24 rounded-full mx-auto"></div>
                  <button className="absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-gray-700 text-white text-xs px-2 py-1 rounded-full">
                    Add Customer Image
                  </button>
                </div>
              </div>
              <div>
                <Link to="/add-customer">
                  <h2 className="text-lg font-semibold">Customer Information</h2>
                </Link>
                <Link to="/measurements">
                  <h2 className="text-lg font-semibold">Measurements</h2>
                </Link>
              </div>
            </div>
            <div className="md:col-span-2 space-y-4">
              <form onSubmit={handleAddCustomerSubmit}>
                <div>
                  <label className="block text-gray-800 font-medium">Customer Firstname:</label>
                  <input
                    type="text"
                    name="firstname"
                    value={customerData.firstname}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Customer Lastname:</label>
                  <input
                    type="text"
                    name="lastname"
                    value={customerData.lastname}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Age:</label>
                  <input
                    type="number"
                    name="age"
                    value={customerData.age}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Gender:</label>
                  <select
                    name="gender"
                    value={customerData.gender}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  >
                    <option value="" disabled>Select Gender</option>
                    <option value="male">Male</option>
                    <option value="female">Female</option>
                    <option value="other">Other</option>
                  </select>
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Email:</label>
                  <input
                    type="email"
                    name="email"
                    value={customerData.email}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Address Line 1:</label>
                  <input
                    type="text"
                    name="address_line_1"
                    value={customerData.address_line_1}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Address Line 2:</label>
                  <input
                    type="text"
                    name="address_line_2"
                    value={customerData.address_line_2}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Nearby Landmark:</label>
                  <input
                    type="text"
                    name="nearby_landmark"
                    value={customerData.nearby_landmark}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Pincode:</label>
                  <input
                    type="text"
                    name="pincode"
                    value={customerData.pincode}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">City:</label>
                  <select
                    name="city_id"
                    value={customerData.city_id}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  >
                    <option value="" disabled>Select City</option>
                    {Array.isArray(cities) && cities.map(city => (
                      <option key={city.id} value={city.id}>{city.name}</option>
                    ))}
                  </select>
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">Mobile Number:</label>
                  <input
                    type="text"
                    name="mobile"
                    value={customerData.mobile}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-gray-700"
                  />
                </div>
                <br />
                <div className="text-center">
                  <button type="submit" className="bg-#0e355b text-#d1d5db px-4 py-2 rounded-md text-sm">
                    Save Information
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddCustomer;
